@@ -1,5 +1,5 @@
 
-# $Id: Ebay.pm,v 2.257 2013-03-02 20:21:17 Martin Exp $
+# $Id: Ebay.pm,v 2.258 2013-03-03 14:33:57 Martin Exp $
 
 =head1 NAME
 
@@ -156,7 +156,7 @@ use WWW::SearchResult 2.072;
 use WWW::Search::Result;
 
 our
-$VERSION = do { my @r = (q$Revision: 2.257 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
+$VERSION = do { my @r = (q$Revision: 2.258 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
 our $MAINTAINER = 'Martin Thurn <mthurn@cpan.org>';
 my $cgi = new CGI;
 
@@ -502,12 +502,19 @@ sub _parse_shipping
     # into the list of international items.
     return 0;
     } # if
+  if (my $oChild = $oTD->look_down(_tag => 'span',
+                                   class => 'ship'))
+    {
+    # As of 2013-03, we need to separate out the price and the
+    # shipping for some flavors of eBay:
+    $oTD = $oChild;
+    } # if
   my $iPrice = $oTD->as_text;
   # I don't know why there are sometimes weird characters in there:
   $iPrice =~ s!&Acirc;!!g;
   $iPrice =~ s!!!g;
   print STDERR " DDD   raw shipping ===$iPrice===\n" if (DEBUG_COLUMNS || (1 < $self->{_debug}));
-  return 1 if ($iPrice !~ m/\d/);
+  return 0 if ($iPrice !~ m/\d/);
   $iPrice =~ s!&pound;!GBP!;
   $hit->shipping($iPrice);
   return 1;
@@ -876,7 +883,7 @@ sub _parse_tree
     print STDERR " DDD   sTitle ===$sTitle===\n" if (1 < $self->{_debug});
     my $oURI = URI->new($oA->attr('href'));
     # next TD unless ($oURI =~ m!ViewItem!);
-    next TD unless ($oURI =~ m!$qrItemNum!);
+    next TD if ($oURI !~ m!$qrItemNum!);
     my $iItemNum = $1;
     my $iCategory = -1;
     $iCategory = $1 if ($oURI =~ m!QQcategoryZ(\d+)QQ!);
@@ -919,12 +926,20 @@ sub _parse_tree
         } # if
       } # if
     my $iCol = 0;
+    my $oTDprev;
+    warn " DDD before loop, there are ", scalar(@aoSibs), " sibling TDs\n" if (1 < $self->{_debug});
  SIBLING_TD:
-    while ((my $oTDsib = shift(@aoSibs))
-           &&
-           (my $sColumn = $asColumns[$iCol++])
-          )
+    while (my $sColumn = $asColumns[$iCol++])
       {
+      warn " DDD just inside loop, there are ", scalar(@aoSibs), " sibling TDs\n" if (1 < $self->{_debug});
+      if ($sColumn =~ m/(repeat|stay|same)/i)
+        {
+        # Re-use the previous table cell for the (next) column of data:
+        unshift @aoSibs, $oTDprev;
+        warn " DDD after unshifting, there are ", scalar(@aoSibs), " sibling TDs\n" if (1 < $self->{_debug});
+        next SIBLING_TD;
+        } # if
+      my $oTDsib = shift(@aoSibs);
       next unless ref($oTDsib);
       my $s = $oTDsib->as_HTML;
       print STDERR " DDD   try TD'$sColumn' ===$s===\n" if (DEBUG_COLUMNS || (1 < $self->{_debug}));
@@ -932,10 +947,9 @@ sub _parse_tree
         {
         next TD unless $self->_parse_price($oTDsib, $hit);
         } # if
-      # As of 2013-03, price and bids are in the same cell, so don't
-      # make this an elsif:
-      if ($sColumn =~ m'bids')
+      elsif ($sColumn =~ m'bids')
         {
+        # It is not a fatal error if there are no bids (i.e. buy-it-now)
         $self->_parse_bids($oTDsib, $hit);
         }
       elsif ($sColumn eq 'shipping')
@@ -971,6 +985,7 @@ sub _parse_tree
         # print STDERR " DDD     do not know how to handle column named $sColumn\n" if (1 < $self->{_debug});
         next SIBLING_TD;
         }
+      $oTDprev = $oTDsib;
       } # while
     my $sDesc = $self->_create_description($hit);
     $hit->description($sDesc);
@@ -1188,7 +1203,7 @@ sub _columns
   {
   my $self = shift;
   # This is for basic USA eBay:
-  return qw( enddate pricebids );
+  return qw( enddate price repeat bids );
   } # _columns
 
 1;
